@@ -43,9 +43,10 @@ from debugEvent import *
 def decrypt_dtc_code(code):
     """Returns the 5-digit DTC code from hex encoding"""
     dtc = ""
-    if len(code)<4:
-        os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"ERROR: Tried to decode bad DTC"')
-        raise "Tried to decode bad DTC: %s" % code
+    print "decrypt_dtc_code_code " + code
+    #if len(code)<4:
+    #   os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"ERROR: Tried to decode bad DTC"')
+    #   raise "Tried to decode bad DTC: %s" % code
 
     tc = obd_sensors.hex_to_int(code[0]) #typecode
     tc = tc >> 2
@@ -107,10 +108,14 @@ class OBDPort:
              except serial.SerialException:
                 self.State = 0
 #mmmm                
-             print "1 response "+self.get_result()
-             response=self.get_result()
-             print "2 response "+response
-             self.ELMver = response
+             response1=self.get_result()
+             print "1 response "+response1
+             if response1=="atz":
+                    response2=self.get_result()
+                    print "2 response "+response2
+                    self.ELMver = response2
+             else:
+                    self.ELMver = response1
 
              wx.PostEvent(self._notify_window, DebugEvent([2,"atz response:" + self.ELMver]))
              print "self.state: "+str(self.State)
@@ -127,10 +132,10 @@ class OBDPort:
              wx.PostEvent(self._notify_window, DebugEvent([2,"atsp0 response:" + answ]))
 
              self.send_command("0100")
-             time.sleep(0.4)
+             time.sleep(0.3)
              ready = self.get_result()
              print "Result: "+ready
-             time.sleep(0.8)
+             time.sleep(0.5)
              wx.PostEvent(self._notify_window, DebugEvent([2,"0100 response1:" + ready]))
 
 #UNABLE TO CONNECT
@@ -184,15 +189,15 @@ class OBDPort:
      def send_command(self, cmd):
          """Internal use only: not a public interface"""
          if self.port:
-             time.sleep(0.05)
+             time.sleep(0.08)
              self.port.flushOutput()
              self.port.flushInput()
-             time.sleep(0.01)
+             time.sleep(0.05)
              for c in cmd:
                  self.port.write(c)
                  time.sleep(0.01)
              self.port.write("\r\n")
-             time.sleep(0.1)
+             time.sleep(0.05)
              wx.PostEvent(self._notify_window, DebugEvent([3,"Send command:" + cmd]))
              print "Send: " + cmd
 
@@ -206,8 +211,8 @@ class OBDPort:
          if len(code) < 7:
              print "BogusCode"
              os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"ERROR: BogusCode"')
-             time.sleep(0.6)
-             raise "BogusCode"
+             time.sleep(0.5)
+             #raise "BogusCode"
              exit
          
          # get the first thing returned, echo should be off
@@ -232,7 +237,7 @@ class OBDPort:
     
      def get_result(self):
          """Internal use only: not a public interface"""
-         time.sleep(0.5)
+         time.sleep(0.4)
          if self.port:
              buffer = ""
              while 1:
@@ -342,7 +347,8 @@ class OBDPort:
           print "DTC freeze result:" + res
 
           a=len(res)
-          if a>8:
+          print "len(res): " + str(a)
+          if a>9:
 
              for i in range(0, 3):
                  DTC_raw = res[3+i*6:5+i*6] + res[6+i*6:8+i*6]
